@@ -164,10 +164,10 @@ fetch_results_afltables <- function(season = NULL, round_number = NULL) {
 
   # Find round number ----
   # QF/EF weekend is tricky as it is the same round number but different code
-  round_levels <- c(
+  round_levels <- c("R0",
     "R1", "R2", "R3", "R4", "R5", "R6", "R7", "R8", "R9",
     "R10", "R11", "R12", "R13", "R14", "R15", "R16", "R17",
-    "R18", "R19", "R20", "R21", "R22", "R23", "R24",
+    "R18", "R19", "R20", "R21", "R22", "R23", "R24", "R25",
     "QF/EF", "SF", "PF", "GF"
   )
   finals <- c("QF", "EF", "SF", "PF", "GF")
