@@ -2,7 +2,7 @@
 #'
 #' @description
 #' `r lifecycle::badge("deprecated")`
-#' 
+#'
 #' This function has been deprecated due to its inefficiency
 #'
 #' @examples
@@ -13,7 +13,9 @@
 #' fetch_results_afltables()
 #' }
 get_score_progression_raw <- function() {
-  lifecycle::deprecate_stop("1.0.0",
-                            "get_score_progression_raw()")
+  lifecycle::deprecate_stop(
+    "1.0.0",
+    "get_score_progression_raw()"
+  )
   return(NULL)
 }
